@@ -50,6 +50,7 @@ struct special_node *specials = nullptr;
 
 int special_count;
 int graph_count = 0;
+double maxspeedval = 1e-47; /* The maximum value among the speed graphs */
 
 std::map<int, double *> graphs;
 
@@ -106,6 +107,7 @@ struct graph {
   Colour first_colour, last_colour;
   double scale;
   char tempgrad;
+  char speedgraph;  /* If the current graph is a speed graph */
 };
 
 struct stippled_hr {
@@ -247,9 +249,10 @@ std::pair<char *, size_t> scan_command(const char *s) {
  * @param[out] obj  struct in which to save width, height and other options
  * @param[in]  args argument string to parse
  * @param[in]  defscale default scale if no scale argument given
+ * @param[in]  speedGraph if graph is network speed graph or not
  * @return whether parsing was successful
  **/
-bool scan_graph(struct text_object *obj, const char *argstr, double defscale) {
+bool scan_graph(struct text_object *obj, const char *argstr, double defscale, char speedGraph) {
   char first_colour_name[1024] = {'\0'};
   char last_colour_name[1024] = {'\0'};
 
@@ -267,6 +270,10 @@ bool scan_graph(struct text_object *obj, const char *argstr, double defscale) {
   g->scale = defscale;
   g->tempgrad = FALSE;
 
+  if (speedGraph) {
+    g->speedgraph = TRUE;
+  }
+
   if (argstr == nullptr) return false;
 
   /* set tempgrad to true if '-t' specified.
@@ -300,15 +307,20 @@ bool scan_graph(struct text_object *obj, const char *argstr, double defscale) {
   last_colour_name[0] = '\0';
   g->scale = defscale;
 
-  /* [height],[width] [color1] [color2] */
+  /* [height],[width] [color1] [color2] 
+   * This could match as [height],[width] [scale] [-l | -t], 
+   * therfore we ensure last_colour_name is not TEMPGRAD or LOGGRAPH */
   if (sscanf(argstr, "%d,%d %s %s", &g->height, &g->width, first_colour_name,
-             last_colour_name) == 4) {
+             last_colour_name) == 4 && 
+             strcmp(last_colour_name, TEMPGRAD) != 0 &&
+             strcmp(last_colour_name, LOGGRAPH) != 0) {
     apply_graph_colours(g, first_colour_name, last_colour_name);
     return true;
   }
   g->height = default_graph_height.get(*state);
   g->width = default_graph_width.get(*state);
   first_colour_name[0] = '\0';
+  last_colour_name[0] = '\0';
 
   /* [height],[width] [scale] */
   if (sscanf(argstr, "%d,%d %lf", &g->height, &g->width, &g->scale) == 3) {
@@ -316,6 +328,7 @@ bool scan_graph(struct text_object *obj, const char *argstr, double defscale) {
   }
   g->height = default_graph_height.get(*state);
   g->width = default_graph_width.get(*state);
+  g->scale = defscale;
 
   /* [height],[width] */
   if (sscanf(argstr, "%d,%d", &g->height, &g->width) == 2) { return true; }
@@ -337,11 +350,17 @@ bool scan_graph(struct text_object *obj, const char *argstr, double defscale) {
   last_colour_name[0] = '\0';
   g->scale = defscale;
 
-  /* [color1] [color2] */
-  if (sscanf(argstr, "%s %s", first_colour_name, last_colour_name) == 2) {
+  /* [color1] [color2] 
+   * This could match as [scale] [-l | -t], 
+   * therfore we ensure last_colour_name is not TEMPGRAD or LOGGRAPH */
+  if (sscanf(argstr, "%s %s", first_colour_name, last_colour_name) == 2 &&
+             strcmp(last_colour_name, TEMPGRAD) != 0 &&
+             strcmp(last_colour_name, LOGGRAPH) != 0) { 
     apply_graph_colours(g, first_colour_name, last_colour_name);
     return true;
   }
+  first_colour_name[0] = '\0';
+  last_colour_name[0] = '\0';
 
   /* [scale] */
   if (sscanf(argstr, "%lf", &g->scale) == 1) { return true; }
@@ -486,6 +505,10 @@ static void graph_append(struct special_node *graph, double f, char showaslog) {
   if (graph->scaled != 0) {
     graph->scale =
         *std::max_element(graph->graph + 0, graph->graph + graph->graph_width);
+    if (graph->speedgraph) {
+        maxspeedval = graph->scale < maxspeedval ? maxspeedval : graph->scale;
+        graph->scale = maxspeedval;
+    }
     if (graph->scale < 1e-47) {
       /* avoid NaN's when the graph is all-zero (e.g. before the first update)
        * there is nothing magical about 1e-47 here */
@@ -610,6 +633,10 @@ void new_graph(struct text_object *obj, char *buf, int buf_max_size,
   }
 #endif
 
+  if (g->speedgraph) {
+    s->speedgraph = TRUE;
+  }
+
   if (store_graph_data_explicitly.get(*state)) {
     if (s->graph) { s->graph = retrieve_graph(g->id, s->graph_width); }
 
